import { Component, OnInit, ViewEncapsulation } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';

@Component({
  selector: 'deposit-history-compose',
  templateUrl: './deposit-history-compose.component.html',
  styles: [
    /* language=SCSS */
    `
      .deposit-history-grid {
        /*                      상태   충전  처리  신청 */
        grid-template-columns: 150px 150px 150px 150px;
      }
    `,
  ],
  encapsulation: ViewEncapsulation.None,
})
export class DepositHistoryComposeComponent implements OnInit {
  composeForm!: FormGroup;
  copyFields: { cc: boolean; bcc: boolean } = {
    cc: false,
    bcc: false,
  };
  quillModules: any = {
    toolbar: [
      ['bold', 'italic', 'underline'],
      [{ align: [] }, { list: 'ordered' }, { list: 'bullet' }],
      ['clean'],
    ],
  };

  /**
   * Constructor
   */
  constructor(
    public matDialogRef: MatDialogRef<DepositHistoryComposeComponent>,
    private _formBuilder: FormBuilder
  ) {}

  depositHistory = [
    {
      state: 'ㄷㄱㄹㅇ',
      chargeMoney: 123000,
      processDate: '2022.08.23',
      applicationDate: '2022.08.23',
    },
    {
      state: 'ㄷㄱㄹㅇ',
      chargeMoney: 123000,
      processDate: '2022.08.23',
      applicationDate: '2022.08.23',
    },
  ];

  // -----------------------------------------------------------------------------------------------------
  // @ Lifecycle hooks
  // -----------------------------------------------------------------------------------------------------

  /**
   * On init
   */
  ngOnInit(): void {
    // Create the form
    this.composeForm = this._formBuilder.group({
      to: ['', [Validators.required, Validators.email]],
      cc: ['', [Validators.email]],
      bcc: ['', [Validators.email]],
      subject: [''],
      body: ['', [Validators.required]],
    });
  }

  // -----------------------------------------------------------------------------------------------------
  // @ Public methods
  // -----------------------------------------------------------------------------------------------------

  /**
   * Show the copy field with the given field name
   *
   * @param name
   */
  showCopyField(name: string): void {
    // Return if the name is not one of the available names
    if (name !== 'cc' && name !== 'bcc') {
      return;
    }

    // Show the field
    this.copyFields[name] = true;
  }

  /**
   * Save and close
   */
  saveAndClose(): void {
    // Save the message as a draft
    this.saveAsDraft();

    // Close the dialog
    this.matDialogRef.close();
  }

  /**
   * Discard the message
   */
  discard(): void {}

  /**
   * Save the message as a draft
   */
  saveAsDraft(): void {}

  /**
   * Send the message
   */
  send(): void {}

  /**
   * Track by function for ngFor loops
   *
   * @param index
   * @param item
   */
  __trackByFn(index: number, item: any): any {
    return item.id || index;
  }
}
